@@ -5,6 +5,8 @@
 Some APIs that can be easily implemented
 """
 from . import *
+from .. import qs_default_console, qs_error_string, qs_info_string, qs_warning_string
+import json
 import requests
 
 
@@ -33,7 +35,7 @@ def rmbg(filePath: str):
         with open(img_root + img_name + '_rmbg.png', 'wb') as imgfile:
             imgfile.write(res.content)
     else:
-        print('ERROR:' if user_lang != 'zh' else '错误:', res.status_code, res.text)
+        qs_default_console.log(qs_error_string, res.status_code, res.text)
 
 
 def smms(filePath: str):
@@ -45,13 +47,15 @@ def smms(filePath: str):
     :param filePath: 图片或Markdown文件的路径
     :return: None
     """
-    from prettytable import PrettyTable
+    import os
+    from rich.table import Table, Column
+    from rich.text import Text
+    from rich.box import SIMPLE
+
     api_key = pre_check('smms')
+    res_tb = Table(*(['File', 'Status', 'url'] if user_lang != 'zh' else ['文件', '状态', '链接']))
 
     def post_img(path: str) -> dict:
-        headers = {
-            'Authorization': api_key,
-        }
         try:
             data = {
                 'smfile': (path.split('/')[-1], open(path, 'rb')),
@@ -59,7 +63,7 @@ def smms(filePath: str):
             }
         except:
             return {}
-        res_json = requests.post('https://sm.ms/api/v2/upload', headers=headers, files=data).text
+        res_json = requests.post('https://sm.ms/api/v2/upload', headers={'Authorization': api_key}, files=data).text
         return json.loads(res_json)
 
     def get_path(rt, rel):
@@ -69,8 +73,6 @@ def smms(filePath: str):
         import re
         _user_path = os.path.expanduser('~')
         rt_path = dir_char.join(os.path.abspath(path).split(dir_char)[:-1]) + dir_char
-        res_tb = PrettyTable()
-        res_tb.field_names = ['File', 'Status', 'url'] if user_lang != 'zh' else ['文件', '状态', '链接']
         img_set = {}
         with open(path, 'r') as fp:
             ct = fp.read()
@@ -82,12 +84,12 @@ def smms(filePath: str):
             if aim not in img_set:
                 res_dict = post_img(aim)
                 if not res_dict:
-                    res_tb.add_row([aim.split(dir_char)[-1], 'No File', ''])
+                    res_tb.add_row(aim.split(dir_char)[-1], 'No File', '')
                     img_set[aim] = False
                 else:
                     res_tb.add_row(
-                        [aim.split(dir_char)[-1], res_dict['success'],
-                         res_dict['message'] if not res_dict['success'] else res_dict['data']['url']]
+                        aim.split(dir_char)[-1], res_dict['success'],
+                        res_dict['message'] if not res_dict['success'] else res_dict['data']['url']
                     )
                     if not res_dict['success'] and res_dict['code'] == 'unauthorized':
                         break
@@ -96,7 +98,7 @@ def smms(filePath: str):
                 ct = ct.replace(raw_path, img_set[aim])
         with open(path, 'w') as fp:
             fp.write(ct)
-        print(res_tb)
+        qs_default_console.print(res_tb, justify="center")
 
     try:
         is_md = filePath.endswith('.md')
@@ -107,13 +109,12 @@ def smms(filePath: str):
             format_markdown(filePath)
         else:
             res = post_img(filePath)
-            tb = PrettyTable(['File', 'Status', 'url'])
             if not res:
-                tb.add_row([filePath.split(dir_char)[-1], 'No File', ''])
+                res_tb.add_row(filePath.split(dir_char)[-1], 'No File', '')
             else:
-                tb.add_row(
-                    [filePath.split(dir_char)[-1], res['success'], '' if not res['success'] else res['data']['url']])
-            print(tb)
+                res_tb.add_row(
+                    filePath.split(dir_char)[-1], res['success'], '' if not res['success'] else res['data']['url'])
+            qs_default_console.print(res_tb, justify="center")
 
 
 def pasteme(key: str = '100', password: str = '', mode: str = 'get'):
@@ -128,33 +129,36 @@ def pasteme(key: str = '100', password: str = '', mode: str = 'get'):
     :return: None
     """
     import pyperclip
-    from colorama import Fore, Style
     if mode == 'get':
         if password:
-            r = requests.get('https://api.pasteme.cn/%s,%s' % (key, password), params={'json': True})
+            r = requests.get(f'https://api.pasteme.cn/{key},{password}', params={'json': True})
         else:
-            r = requests.get('https://api.pasteme.cn/%s' % key, params={'json': True})
+            r = requests.get(f'https://api.pasteme.cn/{key}', params={'json': True})
         if r.status_code == requests.codes.ok:
             js = json.loads(r.content)
             if js['status'] == 200:
                 try:
                     pyperclip.copy(js['content'])
                 except:
-                    print('Sorry, but your system may not be suppported by `pyperclip`'
-                          if user_lang != 'zh' else
-                          '抱歉，但是“pyperclip”不支持你的系统')
+                    qs_default_console.log(
+                        qs_error_string, 'Sorry, but your system may not be suppported by `pyperclip`'
+                        if user_lang != 'zh' else
+                        '抱歉，但是“pyperclip”不支持你的系统')
                 with open("%s.%s" % (key, js['lang']), 'w') as file:
                     file.write(js['content'])
             else:
-                print(Fore.RED, 'Wrong Password' if password else 'Password is required', Style.RESET_ALL)
+                qs_default_console.log(qs_error_string,
+                                       'Wrong Password' if password else 'Password is required')
         else:
-            print(Fore.RED, 'Unknown error' if user_lang != 'zh' else '未知错误', Style.RESET_ALL)
+            qs_default_console.log(qs_error_string, 'Unknown error' if user_lang != 'zh' else '未知错误')
     else:
         try:
             ss = pyperclip.paste()
         except :
-            path = input('Sorry, but your system is not supported by `pyperclip`\nSo you need input content manually: '
-                         if user_lang != 'zh' else '抱歉，但是“pyperclip”不支持你的系统\n，所以你需要手动输入内容:')
+            from .. import qs_default_input
+            path = qs_default_input.ask(
+                'Sorry, but your system is not supported by `pyperclip`\nSo you need input content manually: '
+                if user_lang != 'zh' else '抱歉，但是“pyperclip”不支持你的系统\n，所以你需要手动输入内容:')
             with open(path, 'r') as file:
                 ss = file.read()
         js = {
@@ -167,9 +171,9 @@ def pasteme(key: str = '100', password: str = '', mode: str = 'get'):
                           headers={'Content-Type': 'application/json'},
                           json=js)
         if r.status_code == 201:
-            print(json.loads(r.content))
+            qs_default_console.print(json.loads(r.content))
         else:
-            print('post failed' if user_lang != 'zh' else '发送失败')
+            qs_default_console.print(qs_error_string, 'post failed' if user_lang != 'zh' else '发送失败')
 
 
 def imgs_in_url(url: str):
@@ -184,7 +188,7 @@ def imgs_in_url(url: str):
     from .. import headers
     html = requests.get(url, headers=headers)
     if html.status_code != requests.codes.ok:
-        print('Failed')
+        qs_default_console.log(qs_error_string, 'Network Error' if user_lang != 'zh' else '网络错误')
         return
     import re
     from ..ImageTools.ImagePreview import image_preview
@@ -200,9 +204,10 @@ def imgs_in_url(url: str):
     for url in imgs:
         if not url.startswith('http') or url.endswith('svg'):
             continue
-        print('[Link]' if user_lang != 'zh' else '[链接]', url[:100] + ('' if len(url) <= 100 else '...'))
+        qs_default_console.log(
+            qs_info_string, 'Link:' if user_lang != 'zh' else '链接:', url[:100] + ('' if len(url) <= 100 else '...'))
         if system == 'darwin':
             try:
                 image_preview(url, True)
             except Exception as e:
-                print('[Error]' if user_lang != 'zh' else '[错误]', repr(e))
+                qs_default_console.log(qs_error_string, repr(e))
