@@ -10,7 +10,7 @@ Author: RhythmLian (https://rhythmlian.cn)
 from . import size_format, get_fileinfo
 from concurrent.futures import ThreadPoolExecutor, wait
 from ..ThreadTools import FileWriters
-from .. import user_lang
+from .. import user_lang, qs_default_console, qs_error_string, qs_info_string, qs_warning_string, headers
 from threading import Lock
 from requests import get
 import psutil
@@ -42,7 +42,6 @@ def GetBlockSize(sz):
 
 
 class Downloader:
-    from rich.console import Console
     from rich.progress import (
         BarColumn,
         DownloadColumn,
@@ -52,13 +51,8 @@ class Downloader:
         Progress,
     )
 
-    info_string = '[bold cyan][INFO]' if user_lang != 'zh' else '[bold cyan][信息]'
-    warn_string = '[bold yellow][WARNING]' if user_lang != 'zh' else '[bold yellow][警告]'
-    erro_string = '[bold red][ERROR]' if user_lang != 'zh' else '[bold red][错误]'
-    proxies = {}
-    console = Console()
-
-    def __init__(self, url: str, num: int, set_name: str = '', proxy: str = '', output_error: bool = False):
+    def __init__(self, url: str, num: int, name: str = '', proxy: str = '',
+                 referer: str = '', output_error: bool = False):
         """
         qs普通文件下载引擎
 
@@ -68,28 +62,32 @@ class Downloader:
         :param num: 线程数量
         """
         signal.signal(signal.SIGINT, self._kill_self)
-        self.has_ctrl = False
-        self.url = url
-        self.num = num
-        self.fileLock = Lock()
-        self.url, self.name, r = get_fileinfo(url, proxy)
+        info_flag = True
+        self.url, self.num, self.fileLock, self.output_error, self.proxies = url, num, Lock(), output_error, {}
+        self.url, self.name, r = get_fileinfo(url, proxy, referer)
         if not (self.url and self.name and r):
-            Downloader.console.log(Downloader.warn_string, 'Get File information failed, please check network!'
-                                   if user_lang != 'zh' else '获取文件信息失败，请检查网络!')
-        if set_name:
-            self.name = set_name
+            info_flag = False
+            qs_default_console.print(qs_warning_string, 'Get File information failed, please check network!'
+                                     if user_lang != 'zh' else '获取文件信息失败，请检查网络!')
         if self.name and '.' not in self.name:
             self.name = self.name = os.path.basename(url)
+        if name:
+            self.name = name
         if proxy:
-            Downloader.proxies = {
+            self.proxies = {
                 'http': 'http://'+proxy,
                 'https': 'https://'+proxy
             }
-        self.output_error = output_error
+        self.headers = headers
+        if referer:
+            self.headers['Referer'] = referer
         if not self.url:
-            Downloader.console.log(Downloader.erro_string, 'Connection Error!' if user_lang != 'zh' else '连接失败!')
-            exit(0)
+            qs_default_console.print(qs_error_string, self.name)
+            raise Exception('Connection Error!' if user_lang != 'zh' else '连接失败!')
+
         try:
+            if not info_flag:
+                raise KeyError
             self.size = int(r.headers['content-length'])
             self.main_progress = Downloader.Progress(
                 Downloader.TextColumn("[bold blue]{task.fields[filename]}", justify="right"),
@@ -101,13 +99,13 @@ class Downloader:
                 Downloader.TransferSpeedColumn(),
                 "•",
                 Downloader.TimeRemainingColumn(),
-                console=Downloader.console
+                console=qs_default_console
             )
             self.dl_id = self.main_progress.add_task('Download', filename=self.name, start=False)
             self.main_progress.update(self.dl_id, total=self.size)
             if self.size < 5e6:
-                Downloader.console.log(Downloader.info_string, 'FILE SIZE' if user_lang != 'zh' else '文件大小'
-                                       , size_format(self.size))
+                qs_default_console.print(qs_info_string, 'FILE SIZE' if user_lang != 'zh' else '文件大小'
+                                         , size_format(self.size))
                 self.size = -self.size
             else:
                 self.fileBlock = GetBlockSize(self.size)
@@ -121,7 +119,7 @@ class Downloader:
                 ),
                 Downloader.BarColumn(bar_width=None),
                 Downloader.DownloadColumn(),
-                console=Downloader.console
+                console=qs_default_console
             )
             self.dl_id = self.main_progress.add_task('Download', filename=self.name, start=False)
         if self.size > 0:
@@ -135,10 +133,10 @@ class Downloader:
                 self.ctn_file = open(self.name + '.qs_dl', 'w')
                 self.ctn = []
             self.writers = FileWriters(self.name, max(2, int(core_num / 2)), "rb+" if self.ctn else "wb")
-            Downloader.console.log(Downloader.info_string, 'FILE SIZE' if user_lang != 'zh' else '文件大小'
-                                   , size_format(self.size, align=True))
-            Downloader.console.log(Downloader.info_string, 'BLOCK SIZE' if user_lang != 'zh' else '块大小'
-                                   , size_format(self.fileBlock, align=True))
+            qs_default_console.print(qs_info_string, 'FILE SIZE' if user_lang != 'zh' else '文件大小'
+                                     , size_format(self.size, align=True))
+            qs_default_console.print(qs_info_string, 'BLOCK SIZE' if user_lang != 'zh' else '块大小'
+                                     , size_format(self.fileBlock, align=True))
 
     def _kill_self(self, signum, frame):
         """
@@ -151,13 +149,14 @@ class Downloader:
         :return: None
         """
         if self.size > 0:
-            Downloader.console.print('')
-            Downloader.console.log(Downloader.info_string,
-                                   'Get Ctrl-C, exiting...' if user_lang != 'zh' else '捕获Ctrl-C, 正在退出...')
+            self.main_progress.stop_task(self.dl_id)
+            self.main_progress.stop()
+            qs_default_console.print(qs_info_string,
+                                     'Get Ctrl-C, exiting...' if user_lang != 'zh' else '捕获Ctrl-C, 正在退出...')
             self.ctn_file.close()
             self.pool.shutdown(wait=False)
             self.writers.wait()
-            Downloader.console.log(Downloader.info_string, 'Deal Done!' if user_lang != 'zh' else '处理完成!')
+            qs_default_console.print(qs_info_string, 'Deal Done!' if user_lang != 'zh' else '处理完成!')
         os._exit(0)
 
     def _dl(self, start):
@@ -170,14 +169,15 @@ class Downloader:
         :return: None
         """
         try:
-            _sz = min(start + self.fileBlock, self.size)
-            headers = {'Range': 'bytes={}-{}'.format(start, _sz)}
-            r = get(self.url, headers=headers, timeout=50, proxies=Downloader.proxies)
+            _sz = min(start + self.fileBlock, self.size - 1)
+            _headers = self.headers.copy()
+            _headers['Range'] = 'bytes={}-{}'.format(start, _sz)
+            r = get(self.url, headers=_headers, timeout=50, proxies=self.proxies)
             self.writers.new_job(r.content, start)
         except Exception as e:
             msg = repr(e)
             if self.output_error:
-                Downloader.console.log(Downloader.erro_string, msg[:msg.index('(')])
+                qs_default_console.print(qs_error_string, msg[:msg.index('(')])
             self.job_queue.put(start)
         else:
             self.fileLock.acquire()
@@ -194,7 +194,7 @@ class Downloader:
 
         :return: None
         """
-        r = get(self.url, stream=True, proxies=Downloader.proxies)
+        r = get(self.url, stream=True, proxies=self.proxies, headers=self.headers)
         flag = self.size != -1
 
         if flag:
@@ -239,8 +239,8 @@ class Downloader:
                         self.futures.append(self.pool.submit(self._dl, cur))
                 wait(self.futures)
                 if not self.job_queue.empty() and retry_cnt > 2:
-                    Downloader.console.log(Downloader.warn_string, 'Exists File Block Lost, Retrying after 0.5 sec'
-                                           if user_lang != 'zh' else '存在文件块丢失，0.5秒后重试')
+                    qs_default_console.print(qs_warning_string, 'Exists File Block Lost, Retrying after 0.5 sec'
+                                             if user_lang != 'zh' else '存在文件块丢失，0.5秒后重试')
                     time.sleep(0.5)
                 retry_cnt += 1
             self.writers.wait()
@@ -249,10 +249,10 @@ class Downloader:
         else:
             self._single_dl()
         self.main_progress.stop()
-        Downloader.console.log(Downloader.info_string, self.name, 'download done!' if user_lang != 'zh' else '下载完成!')
+        qs_default_console.print(qs_info_string, self.name, 'download done!' if user_lang != 'zh' else '下载完成!')
 
 
-def normal_dl(url, set_name: str = '', set_proxy: str = '', output_error: bool = False):
+def normal_dl(url, set_name: str = '', set_proxy: str = '', set_referer: str = '', output_error: bool = False):
     """
     自动规划下载线程数量并开始并行下载
 
@@ -261,10 +261,11 @@ def normal_dl(url, set_name: str = '', set_proxy: str = '', output_error: bool =
     :param url: 文件url
     :param set_name: 设置文件名（默认采用url所指向的资源名）
     :param set_proxy: 设置代理（默认无代理）
+    :param set_referer: 设置referer
     :param output_error: 输出报错信息
     :return: None
     """
-    Downloader(url, min(16, core_num * 4), set_name, set_proxy, output_error).run()
+    Downloader(url, min(16, core_num * 4), set_name, set_proxy, set_referer, output_error).run()
 
 
 if __name__ == '__main__':
