@@ -49,14 +49,15 @@ def download():
     Qs download engine, use --video or -v use the default video download engine download
     """
     if any([i in sys.argv for i in ['-h', '-help', '--help']]):
-        from . import user_lang
-        print('Usage: qs -dl [url...]\n'
-              '  [--video] | [-v]  :-> download video (use youtube-dl)\n'
-              '  [--proxy] | [-px] :-> use default proxy set in ~/.qsrc'
-              if user_lang != 'zh' else
-              '使用: qs -dl [链接...]\n'
-              '  [--video] | [-v]  :-> 使用youtube-dl下载视频\n'
-              '  [--proxy] | ]-px] :-> 使用配置表中的默认代理下载')
+        from . import user_lang, qs_default_console, qs_error_string
+        qs_default_console.print(
+            qs_error_string, 'Usage: qs dl [url...]\n'
+            '  [--video] | [-v]  :-> download video (use youtube-dl)\n'
+            '  [--proxy] | [-px] :-> use default proxy set in ~/.qsrc'
+            if user_lang != 'zh' else
+            '使用: qs -dl [链接...]\n'
+            '  [--video] | [-v]  :-> 使用youtube-dl下载视频\n'
+            '  [--proxy] | [-px] :-> 使用配置表中的默认代理下载')
         return
     global _real_main
     ytb_flag = '--video' in sys.argv or '-v' in sys.argv
@@ -83,7 +84,8 @@ def download():
                 else:
                     normal_dl(url) if not ytb_flag else _real_main([url, '--merge-output-format', 'mp4'])
     else:
-        print("No url found!")
+        from . import user_lang, qs_default_console, qs_error_string
+        qs_default_console.log(qs_error_string, "No url found!" if user_lang != 'zh' else '无链接输入')
 
 
 def http():
@@ -102,7 +104,7 @@ def http():
                 from .NetTools import formatUrl
                 url = formatUrl(url)
             except IndexError:
-                print('Usage: qs -ftp ip:port -bind url')
+                print('Usage: qs ftp ip:port -bind url')
                 exit(0)
     else:
         from .NetTools import get_ip
@@ -122,29 +124,38 @@ def netinfo():
     """
     import socket
     import pyperclip
-    import prettytable
     import urllib.parse
-    from . import user_lang
+    from . import user_lang, qs_default_console, qs_error_string
     from .API.alapi import ip_info
 
     def print_ip_info(info_ls):
-        table = prettytable.PrettyTable(
-            ['ip', '运营商', '地址', '经纬'] if user_lang == 'zh' else ['ip', 'isp', 'pos', 'location']
+        from rich.table import Table, Column
+        from rich import box
+
+        table = Table(
+            *([
+                  Column('ip', justify='center', style='bold magenta'), Column('运营商', justify='center'),
+                  Column('地址', justify='center'), Column('经纬', justify='center')]
+              if user_lang == 'zh' else [
+                  Column('ip', justify='center', style='bold magenta'), Column('isp', justify='center'),
+                  Column('pos', justify='center'), Column('location', justify='center')
+            ]), row_styles=['none', 'dim'], show_edge=False, box=box.SIMPLE
         )
         for info in info_ls:
-            table.add_row([info['ip'],
-                           info['isp'].strip() if 'isp' in info else '未知', info['pos'],
-                           str(info['location'])[1:-1].replace("'", '')])
-        print(table)
+            table.add_row(info['ip'],
+                          info['isp'].strip() if 'isp' in info else '未知', info['pos'],
+                          str(info['location'])[1:-1].replace("'", ''))
+        qs_default_console.print(table, justify="center")
 
     urls = sys.argv[2:] if len(sys.argv) > 2 else []
     if not urls:
         try:
             urls += pyperclip.paste().strip().split() if not urls else []
         except :
-            urls = input('Sorry, but your system is not supported by `pyperclip`\nSo you need input content manually: '
-                         if user_lang != 'zh' else '抱歉，但是“pyperclip”不支持你的系统\n，所以你需要手动输入内容:')\
-                .strip().split()
+            urls = qs_default_console.ask(
+                'Sorry, but your system is not supported by `pyperclip`\nSo you need input content manually: '
+                if user_lang != 'zh' else '抱歉，但是“pyperclip”不支持你的系统\n，所以你需要手动输入内容:'
+            ).strip().split()
     if not urls:
         urls.append('me')
     res_ls = []
@@ -160,7 +171,7 @@ def netinfo():
                     addr = socket.getaddrinfo(addr if addr else i, 'http')[0][-1][0]
             res_ls.append(ip_info(addr))
         except:
-            print('[ERROR] Get domain failed:', i)
+            qs_default_console.print(qs_error_string, 'Get domain failed:', i)
             continue
     print_ip_info(res_ls)
 
@@ -173,17 +184,25 @@ def wifi():
 
     :return:
     """
-    from . import system, user_lang
-    from prettytable import PrettyTable
+    from . import system, user_lang, qs_default_console, qs_error_string, qs_info_string
+    from rich.table import Table, Column
+    from rich.box import SIMPLE
     if system.lower() != 'darwin':
         from .NetTools.WiFi import WiFi
     else:
         from .NetTools.WiFiDarwin import WiFi
     _wifi = WiFi()
-    table = PrettyTable(['id', 'ssid', 'signal', 'lock'] if user_lang != 'zh' else ['序号', '名称', '信号', '加密'])
+    table = Table(*(
+        [Column('id', justify='center'), Column('ssid', justify='center'),
+         Column('signal', justify='center'), Column('lock', justify='center')]
+        if user_lang != 'zh' else
+        [Column('序号', justify='center'), Column('名称', justify='center'),
+         Column('信号', justify='center'), Column('加密', justify='center')])
+        , row_styles=['none', 'dim'], show_edge=False, box=SIMPLE, title='[bold underline] Wi-Fi'
+    )
     connectable_wifi = _wifi.scan()
     if not connectable_wifi:
-        print("No available wifi" if user_lang != 'zh' else '没有可用的wifi')
+        qs_default_console.print(qs_error_string, "No available wifi" if user_lang != 'zh' else '没有可用的wifi')
         return
 
     from PyInquirer import prompt
@@ -211,13 +230,14 @@ def wifi():
     }]
 
     for i, l in enumerate(connectable_wifi):
-        table.add_row([i] + l)
-    print(table)
+        table.add_row(*([str(i)] + [str(j) for j in l]))
+    qs_default_console.print(table, justify="center")
 
     res = prompt(questions)
     if not res:
         return
     ssid = connectable_wifi[int(res['ssid'])]
     password = res['password']
-    print('Connect succeed' if user_lang != 'zh' else '连接成功') \
-        if _wifi.conn(ssid, password) else print('Connect failed' if user_lang != 'zh' else '连接失败')
+    qs_default_console.print(qs_info_string, 'Connect succeed' if user_lang != 'zh' else '连接成功') \
+        if _wifi.conn(ssid, password) else \
+        qs_default_console.print(qs_error_string, 'Connect failed' if user_lang != 'zh' else '连接失败')
